@@ -1,7 +1,7 @@
 package CPAN::SQLite::CPANMeta;
 
-our $DATE = '2015-01-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-01-10'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,8 +13,6 @@ use Archive::Tar;
 use File::Slurp::Tiny qw(read_file);
 #use File::Temp qw(tempdir);
 use JSON;
-use Module::CoreList;
-use Version::Util qw(version_gt);
 use YAML::Syck ();
 
 use Exporter;
@@ -364,236 +362,6 @@ ORDER BY dist_file
     [200];
 }
 
-# XXX cache connection?
-
-sub _get_prereqs {
-    my ($mod, $dbh, $memory, $level, $max_level, $phase, $rel, $include_core, $plver) = @_;
-
-    $log->tracef("Finding dependencies for module %s (level=%i) ...", $mod, $level);
-
-    # first find out which distribution that module belongs to
-    my $sth = $dbh->prepare("SELECT dist_id FROM mods WHERE mod_name=?");
-    $sth->execute($mod);
-    my $modrec = $sth->fetchrow_hashref;
-    return [404, "No such module: $mod"] unless $modrec;
-
-    # fetch the dependency information
-    $sth = $dbh->prepare("SELECT
-  CASE WHEN dp.mod_id THEN (SELECT mod_name FROM mods WHERE mod_id=dp.mod_id) ELSE dp.mod_name END AS module,
-  phase,
-  rel,
-  version
-FROM deps dp
-WHERE dp.dist_id=?
-ORDER BY module");
-    $sth->execute($modrec->{dist_id});
-    my @res;
-    while (my $row = $sth->fetchrow_hashref) {
-        next unless $phase eq 'ALL' || $row->{phase} eq $phase;
-        next unless $rel   eq 'ALL' || $row->{rel}   eq $rel;
-        #say "include_core=$include_core, is_core($row->{module}, $row->{version}, $plver)=", Module::CoreList::is_core($row->{module}, $row->{version}, version->parse($plver)->numify);
-        next if !$include_core && Module::CoreList::is_core($row->{module}, $row->{version}, version->parse($plver)->numify);
-        if (defined $memory->{$row->{module}}) {
-            if (version_gt($row->{version}, $memory->{$row->{module}})) {
-                $memory->{$row->{version}} = $row->{version};
-            }
-            next;
-        }
-        delete $row->{phase} unless $phase eq 'ALL';
-        delete $row->{rel}   unless $rel   eq 'ALL';
-        $row->{level} = $level;
-        push @res, $row;
-        $memory->{$row->{module}} = $row->{version};
-    }
-
-    if (@res && ($max_level==-1 || $level < $max_level)) {
-        my $i = @res-1;
-        while ($i >= 0) {
-            my $subres = _get_prereqs($res[$i]{module}, $dbh, $memory,
-                                      $level+1, $max_level, $phase, $rel, $include_core, $plver);
-            $i--;
-            next if $subres->[0] != 200;
-            splice @res, $i+2, 0, @{$subres->[2]};
-        }
-    }
-
-    [200, "OK", \@res];
-}
-
-sub _get_revdeps {
-    my ($mod, $dbh) = @_;
-
-    $log->tracef("Finding reverse dependencies for module %s ...", $mod);
-
-    # first, check that module is listed
-    my ($mod_id) = $dbh->selectrow_array("SELECT mod_id FROM mods WHERE mod_name=?", {}, $mod)
-        or return [404, "No such module: $mod"];
-
-    # get all dists that depend on that module
-    my $sth = $dbh->prepare("SELECT
-  (SELECT dist_name FROM dists WHERE dp.dist_id=dists.dist_id) AS dist,
-  (SELECT dist_vers FROM dists WHERE dp.dist_id=dists.dist_id) AS dist_version,
-  -- phase,
-  -- rel,
-  version req_version
-FROM deps dp
-WHERE mod_id=?
-ORDER BY dist");
-    $sth->execute($mod_id);
-    my @res;
-    while (my $row = $sth->fetchrow_hashref) {
-        #next unless $phase eq 'ALL' || $row->{phase} eq $phase;
-        #next unless $rel   eq 'ALL' || $row->{rel}   eq $rel;
-        #delete $row->{phase} unless $phase eq 'ALL';
-        #delete $row->{rel}   unless $rel   eq 'ALL';
-        push @res, $row;
-    }
-
-    [200, "OK", \@res];
-}
-
-my $_complete_mod = sub {
-    my %args = @_;
-
-    my $word = $args{word} // '';
-
-    my $cmdline = $args{cmdline} or return undef;
-    my $r = $args{r};
-
-    # force read config file, because by default it is turned off when in
-    # completion
-    $r->{read_config} = 1;
-    my $res = $cmdline->parse_argv($r);
-
-    my $dbh;
-    eval { $dbh = _connect_db(%{$res->[2]}) };
-
-    # if we can't connect (probably because --cpan is not set yet), bail
-    if ($@) {
-        $log->tracef("[comp] can't connect to db, bailing: %s", $@);
-        return undef;
-    }
-
-    my $sth = $dbh->prepare(
-        "SELECT mod_name FROM mods WHERE mod_name LIKE ? ORDER BY mod_name");
-    $sth->execute($word . '%');
-
-    # XXX follow Complete::OPT_CI
-
-    my @res;
-    while (my ($mod) = $sth->fetchrow_array) {
-        # only complete one level deeper at a time
-        if ($mod =~ /:\z/) {
-            next unless $mod =~ /\A\Q$word\E:*\w+\z/i;
-        } else {
-            next unless $mod =~ /\A\Q$word\E\w*(::\w+)?\z/i;
-        }
-        push @res, $mod;
-    }
-
-    \@res;
-};
-
-my %mod_args = (
-    module => {
-        schema => 'str*',
-        req => 1,
-        pos => 0,
-        completion => $_complete_mod,
-    },
-);
-
-my %deps_args = (
-    phase => {
-        schema => ['str*' => {
-            in => [qw/develop configure build runtime test ALL/],
-        }],
-        default => 'runtime',
-    },
-    rel => {
-        schema => ['str*' => {
-            in => [qw/requires recommends suggests conflicts ALL/],
-        }],
-        default => 'requires',
-    },
-    level => {
-        summary => 'Recurse for a number of levels (-1 means unlimited)',
-        schema  => 'int*',
-        default => 1,
-        cmdline_aliases => {
-            l => {},
-            R => {
-                summary => 'Recurse (alias for `--level -1`)',
-                is_flag => 1,
-                code => sub { $_[0]{level} = -1 },
-            },
-        },
-    },
-    include_core => {
-        summary => 'Include Perl core modules',
-        'summary.alt.bool.not' => 'Exclude Perl core modules',
-        schema  => 'bool',
-        default => 0,
-    },
-    perl_version => {
-        summary => 'Set base Perl version for determining core modules',
-        schema  => 'str*',
-        default => "$^V",
-        cmdline_aliases => {V=>{}},
-    },
-);
-
-$SPEC{'deps_cpan_meta'} = {
-    v => 1.1,
-    summary => 'Query dependency from CPAN::SQLite database',
-    args => {
-        %common_args,
-        %deps_args,
-    },
-};
-sub deps_cpan_meta {
-    my %args = @_;
-
-    my $cpan    = $args{cpan} or return [400, "Please specify 'cpan'"];
-    my $mod     = $args{module};
-    my $phase   = $args{phase} // 'runtime';
-    my $rel     = $args{rel} // 'requires';
-    my $plver   = $args{perl_version} // "$^V";
-    my $level   = $args{level} // 1;
-    my $include_core = $args{include_core} // 0;
-
-    my $dbh     = _connect_db(%args);
-
-    my $res = _get_prereqs($mod, $dbh, {}, 1, $level, $phase, $rel, $include_core, $plver);
-
-    return $res unless $res->[0] == 200;
-    for (@{$res->[2]}) {
-        $_->{module} = ("  " x ($_->{level}-1)) . $_->{module};
-        delete $_->{level};
-    }
-
-    $res;
-}
-
-$SPEC{'revdeps_cpan_meta'} = {
-    v => 1.1,
-    summary => 'Query reverse dependencies from CPAN::SQLite database',
-    args => {
-        %common_args,
-        %mod_args,
-    },
-};
-sub revdeps_cpan_meta {
-    my %args = @_;
-
-    my $cpan    = $args{cpan} or return [400, "Please specify 'cpan'"];
-    my $mod     = $args{module};
-
-    my $dbh     = _connect_db(%args);
-
-    _get_revdeps($mod, $dbh);
-}
-
 1;
 # ABSTRACT: Index and query CPAN Meta information in CPAN::SQLite database
 
@@ -609,7 +377,7 @@ CPAN::SQLite::CPANMeta - Index and query CPAN Meta information in CPAN::SQLite d
 
 =head1 VERSION
 
-This document describes version 0.04 of CPAN::SQLite::CPANMeta (from Perl distribution CPAN-SQLite-CPANMeta), released on 2015-01-09.
+This document describes version 0.05 of CPAN::SQLite::CPANMeta (from Perl distribution CPAN-SQLite-CPANMeta), released on 2015-01-10.
 
 =head1 SYNOPSIS
 
@@ -635,56 +403,6 @@ extracted/recorded are: dependencies (tables: C<files>, C<deps>).
 =head1 FUNCTIONS
 
 
-=head2 deps_cpan_meta(%args) -> [status, msg, result, meta]
-
-Query dependency from CPAN::SQLite database.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<cpan>* => I<str>
-
-Location of your local CPAN mirror, e.g. /path/to/cpan.
-
-=item * B<db_dir> => I<str>
-
-Database directory, defaults to your CPAN home.
-
-=item * B<db_name> => I<str> (default: "cpandb.sql")
-
-Database name.
-
-=item * B<include_core> => I<bool> (default: 0)
-
-Include Perl core modules.
-
-=item * B<level> => I<int> (default: 1)
-
-Recurse for a number of levels (-1 means unlimited).
-
-=item * B<perl_version> => I<str> (default: "v5.18.4")
-
-Set base Perl version for determining core modules.
-
-=item * B<phase> => I<str> (default: "runtime")
-
-=item * B<rel> => I<str> (default: "requires")
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
-
 =head2 index_cpan_meta(%args) -> [status, msg, result, meta]
 
 Index CPAN Meta information into CPAN::SQLite database.
@@ -718,42 +436,6 @@ that contains extra information.
 
 Return value:  (any)
 
-
-=head2 revdeps_cpan_meta(%args) -> [status, msg, result, meta]
-
-Query reverse dependencies from CPAN::SQLite database.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<cpan>* => I<str>
-
-Location of your local CPAN mirror, e.g. /path/to/cpan.
-
-=item * B<db_dir> => I<str>
-
-Database directory, defaults to your CPAN home.
-
-=item * B<db_name> => I<str> (default: "cpandb.sql")
-
-Database name.
-
-=item * B<module>* => I<str>
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
 =head1 SEE ALSO
 
 Front-end for this module: L<cpandb-cpanmeta>.
